define(
//begin v1.x content
{
	"field-tue-relative+-1": "letzten Dienstag",
	"field-year": "Jahr",
	"field-wed-relative+0": "diesen Mittwoch",
	"field-wed-relative+1": "nächsten Mittwoch",
	"field-minute": "Minute",
	"field-month-narrow-relative+-1": "letzten Monat",
	"field-tue-narrow-relative+0": "diesen Di.",
	"field-tue-narrow-relative+1": "nächsten Di.",
	"field-thu-short-relative+0": "diesen Do.",
	"field-day-short-relative+-1": "gestern",
	"field-thu-short-relative+1": "nächsten Do.",
	"field-day-relative+0": "heute",
	"field-day-short-relative+-2": "vorgestern",
	"field-day-relative+1": "morgen",
	"field-week-narrow-relative+0": "diese Woche",
	"field-day-relative+2": "übermorgen",
	"field-week-narrow-relative+1": "nächste Woche",
	"field-wed-narrow-relative+-1": "letzten Mi.",
	"field-year-narrow": "J",
	"field-era-short": "Epoche",
	"field-year-narrow-relative+0": "dieses Jahr",
	"field-tue-relative+0": "diesen Dienstag",
	"field-year-narrow-relative+1": "nächstes Jahr",
	"field-tue-relative+1": "nächsten Dienstag",
	"field-weekdayOfMonth": "Wochentag",
	"field-second-short": "Sek.",
	"field-weekdayOfMonth-narrow": "WT",
	"field-week-relative+0": "diese Woche",
	"field-month-relative+0": "diesen Monat",
	"field-week-relative+1": "nächste Woche",
	"field-month-relative+1": "nächsten Monat",
	"field-sun-narrow-relative+0": "diesen So.",
	"field-mon-short-relative+0": "diesen Mo.",
	"field-sun-narrow-relative+1": "nächsten So.",
	"field-mon-short-relative+1": "nächsten Mo.",
	"field-second-relative+0": "jetzt",
	"eraNames": [
		"vor Volksrepublik China",
		"Minguo"
	],
	"field-weekOfMonth": "Woche des Monats",
	"field-month-short": "Monat",
	"field-day": "Tag",
	"field-dayOfYear-short": "Tag des Jahres",
	"field-year-relative+-1": "letztes Jahr",
	"field-sat-short-relative+-1": "letzten Sa.",
	"field-hour-relative+0": "in dieser Stunde",
	"field-wed-relative+-1": "letzten Mittwoch",
	"field-sat-narrow-relative+-1": "letzten Sa.",
	"field-second": "Sekunde",
	"field-hour-short-relative+0": "in dieser Stunde",
	"field-quarter": "Quartal",
	"field-week-short": "Woche",
	"field-day-narrow-relative+0": "heute",
	"field-day-narrow-relative+1": "morgen",
	"field-day-narrow-relative+2": "übermorgen",
	"field-tue-short-relative+0": "diesen Di.",
	"field-tue-short-relative+1": "nächsten Di.",
	"field-month-short-relative+-1": "letzten Monat",
	"field-mon-relative+-1": "letzten Montag",
	"field-month": "Monat",
	"field-day-narrow": "Tag",
	"field-minute-short": "Min.",
	"field-dayperiod": "Tageshälfte",
	"field-sat-short-relative+0": "diesen Sa.",
	"field-sat-short-relative+1": "nächsten Sa.",
	"eraAbbr": [
		"Before R.O.C.",
		"Minguo"
	],
	"field-second-narrow": "Sek.",
	"field-mon-relative+0": "diesen Montag",
	"field-mon-relative+1": "nächsten Montag",
	"field-day-narrow-relative+-1": "gestern",
	"field-year-short": "Jahr",
	"field-day-narrow-relative+-2": "vorgestern",
	"field-quarter-relative+-1": "letztes Quartal",
	"field-dayperiod-narrow": "Tagesh.",
	"field-week-narrow-relative+-1": "letzte Woche",
	"field-dayOfYear": "Tag des Jahres",
	"field-sat-relative+-1": "letzten Samstag",
	"field-hour": "Stunde",
	"field-minute-narrow-relative+0": "in dieser Minute",
	"field-month-relative+-1": "letzten Monat",
	"field-quarter-short": "Quart.",
	"field-sat-narrow-relative+0": "diesen Sa.",
	"field-fri-relative+0": "diesen Freitag",
	"field-sat-narrow-relative+1": "nächsten Sa.",
	"field-fri-relative+1": "nächsten Freitag",
	"field-month-narrow-relative+0": "diesen Monat",
	"field-month-narrow-relative+1": "nächsten Monat",
	"field-sun-short-relative+0": "diesen So.",
	"field-sun-short-relative+1": "nächsten So.",
	"field-week-relative+-1": "letzte Woche",
	"field-minute-short-relative+0": "in dieser Minute",
	"field-quarter-relative+0": "dieses Quartal",
	"field-minute-relative+0": "in dieser Minute",
	"field-quarter-relative+1": "nächstes Quartal",
	"field-wed-short-relative+-1": "letzten Mi.",
	"field-thu-short-relative+-1": "letzten Do.",
	"field-year-narrow-relative+-1": "letztes Jahr",
	"field-mon-narrow-relative+-1": "letzten Mo.",
	"field-thu-narrow-relative+-1": "letzten Do.",
	"field-tue-narrow-relative+-1": "letzten Di.",
	"field-weekOfMonth-short": "W/M",
	"field-wed-short-relative+0": "diesen Mi.",
	"field-wed-short-relative+1": "nächsten Mi.",
	"field-sun-relative+-1": "letzten Sonntag",
	"field-weekday": "Wochentag",
	"field-day-short-relative+0": "heute",
	"field-quarter-narrow-relative+0": "dieses Quartal",
	"field-sat-relative+0": "diesen Samstag",
	"field-day-short-relative+1": "morgen",
	"field-quarter-narrow-relative+1": "nächstes Quartal",
	"field-sat-relative+1": "nächsten Samstag",
	"field-day-short-relative+2": "übermorgen",
	"field-week-short-relative+0": "diese Woche",
	"field-week-short-relative+1": "nächste Woche",
	"field-dayOfYear-narrow": "T/J",
	"field-month-short-relative+0": "diesen Monat",
	"field-month-short-relative+1": "nächsten Monat",
	"field-weekdayOfMonth-short": "Wochentag",
	"field-zone-narrow": "Zeitz.",
	"field-thu-narrow-relative+0": "diesen Do.",
	"field-thu-narrow-relative+1": "nächsten Do.",
	"field-sun-narrow-relative+-1": "letzten So.",
	"field-mon-short-relative+-1": "letzten Mo.",
	"field-thu-relative+0": "diesen Donnerstag",
	"field-thu-relative+1": "nächsten Donnerstag",
	"field-fri-short-relative+-1": "letzten Fr.",
	"field-thu-relative+-1": "letzten Donnerstag",
	"field-week": "Woche",
	"field-wed-narrow-relative+0": "diesen Mi.",
	"field-wed-narrow-relative+1": "nächsten Mi.",
	"field-quarter-narrow-relative+-1": "letztes Quartal",
	"field-year-short-relative+0": "dieses Jahr",
	"field-dayperiod-short": "Tageshälfte",
	"field-year-short-relative+1": "nächstes Jahr",
	"field-fri-short-relative+0": "diesen Fr.",
	"field-fri-short-relative+1": "nächsten Fr.",
	"field-week-short-relative+-1": "letzte Woche",
	"field-hour-narrow-relative+0": "in dieser Stunde",
	"field-hour-short": "Std.",
	"field-zone-short": "Zeitzone",
	"field-month-narrow": "M",
	"field-hour-narrow": "Std.",
	"field-fri-narrow-relative+-1": "letzten Fr.",
	"field-year-relative+0": "dieses Jahr",
	"field-year-relative+1": "nächstes Jahr",
	"field-era-narrow": "E",
	"field-fri-relative+-1": "letzten Freitag",
	"eraNarrow": [
		"v. VR China",
		"Minguo"
	],
	"field-tue-short-relative+-1": "letzten Di.",
	"field-minute-narrow": "Min.",
	"field-mon-narrow-relative+0": "diesen Mo.",
	"field-mon-narrow-relative+1": "nächsten Mo.",
	"field-year-short-relative+-1": "letztes Jahr",
	"field-zone": "Zeitzone",
	"field-weekOfMonth-narrow": "Wo. des Monats",
	"field-weekday-narrow": "Wochent.",
	"field-quarter-narrow": "Q",
	"field-sun-short-relative+-1": "letzten So.",
	"field-day-relative+-1": "gestern",
	"field-day-relative+-2": "vorgestern",
	"field-weekday-short": "Wochentag",
	"field-sun-relative+0": "diesen Sonntag",
	"field-sun-relative+1": "nächsten Sonntag",
	"field-day-short": "Tag",
	"field-week-narrow": "W",
	"field-era": "Epoche",
	"field-fri-narrow-relative+0": "diesen Fr.",
	"field-fri-narrow-relative+1": "nächsten Fr."
}
//end v1.x content
);